pub struct EntityTree {
pub path: EntityPath,
pub children: BTreeMap<EntityPathPart, Self>,
}Expand description
A recursive tree structure that maintains the entity hierarchy.
The tree contains a list of subtrees, and so on recursively.
Fields
path: EntityPathFull path prefix to the root of this (sub)tree.
children: BTreeMap<EntityPathPart, Self>Direct descendants of this (sub)tree.
Implementations
Sourceimpl EntityTree
impl EntityTree
pub fn root() -> Self
pub fn new(path: EntityPath) -> Self
pub fn on_new_entity(&mut self, entity_path: &EntityPath)
pub fn subtree(&self, path: &EntityPath) -> Option<&Self>
Sourcepub fn visit_children_recursively(&self, visitor: impl FnMut(&EntityPath))
pub fn visit_children_recursively(&self, visitor: impl FnMut(&EntityPath))
Invokes visitor for self and all children recursively.
Sourcepub fn prune_empty_entities(
&mut self,
entity_has_data: &impl Fn(&EntityPath) -> bool,
)
pub fn prune_empty_entities( &mut self, entity_has_data: &impl Fn(&EntityPath) -> bool, )
Removes leaf entities that have no children and for which entity_has_data returns false.
This is called after store deletions to keep the tree in sync with the actual data.
Sourcepub fn find_first_child_recursive(
&self,
predicate: impl FnMut(&EntityPath) -> bool,
) -> Option<&Self>
pub fn find_first_child_recursive( &self, predicate: impl FnMut(&EntityPath) -> bool, ) -> Option<&Self>
Invokes the predicate for self and all children recursively,
returning the first entity for which the predicate returns true.
Note that this function has early return semantics, meaning if multiple
entities would return true, only the first is returned.
The entities are yielded in order of their entity paths.